==> chaosmesh-model-5.1.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/TimeChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface TimeChaosStatusFluent<A extends TimeChaosStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildExperiment instead.
 * @return The buildable object.
 */
@Deprecated public ExperimentStatus getExperiment();
    public ExperimentStatus buildExperiment();
    public A withExperiment(ExperimentStatus experiment);
    public Boolean hasExperiment();
    public TimeChaosStatusFluent.ExperimentNested<A> withNewExperiment();
    public TimeChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
    public TimeChaosStatusFluent.ExperimentNested<A> editExperiment();
    public TimeChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
    public TimeChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
    public String getFailedMessage();
    public A withFailedMessage(String failedMessage);
    public Boolean hasFailedMessage();
    public A withNewFailedMessage(String arg1);
    public A withNewFailedMessage(StringBuilder arg1);
    public A withNewFailedMessage(StringBuffer arg1);
    public String getPhase();
    public A withPhase(String phase);
    public Boolean hasPhase();
    public A withNewPhase(String arg1);
    public A withNewPhase(StringBuilder arg1);
    public A withNewPhase(StringBuffer arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(String arg1);
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public ScheduleStatus getScheduler();
    public ScheduleStatus buildScheduler();
    public A withScheduler(ScheduleStatus scheduler);
    public Boolean hasScheduler();
    public A withNewScheduler(String nextRecover,String nextStart);
    public TimeChaosStatusFluent.SchedulerNested<A> withNewScheduler();
    public TimeChaosStatusFluent.SchedulerNested<A> withNewSchedulerLike(ScheduleStatus item);
    public TimeChaosStatusFluent.SchedulerNested<A> editScheduler();
    public TimeChaosStatusFluent.SchedulerNested<A> editOrNewScheduler();
    public TimeChaosStatusFluent.SchedulerNested<A> editOrNewSchedulerLike(ScheduleStatus item);
    public interface ExperimentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExperimentStatusFluent<TimeChaosStatusFluent.ExperimentNested<N>> {

            public N and();
            public N endExperiment();    }


    public interface SchedulerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ScheduleStatusFluent<TimeChaosStatusFluent.SchedulerNested<N>> {

            public N and();
            public N endScheduler();    }


}

==> chaosmesh-model-5.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/TimeChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface TimeChaosStatusFluent<A extends TimeChaosStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildExperiment instead.
 * @return The buildable object.
 */
@Deprecated public ExperimentStatus getExperiment();
    public ExperimentStatus buildExperiment();
    public A withExperiment(ExperimentStatus experiment);
    public Boolean hasExperiment();
    public TimeChaosStatusFluent.ExperimentNested<A> withNewExperiment();
    public TimeChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
    public TimeChaosStatusFluent.ExperimentNested<A> editExperiment();
    public TimeChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
    public TimeChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
    public String getFailedMessage();
    public A withFailedMessage(String failedMessage);
    public Boolean hasFailedMessage();
    public A withNewFailedMessage(StringBuilder arg1);
    public A withNewFailedMessage(int[] arg1,int arg2,int arg3);
    public A withNewFailedMessage(char[] arg1);
    public A withNewFailedMessage(StringBuffer arg1);
    public A withNewFailedMessage(byte[] arg1,int arg2);
    public A withNewFailedMessage(byte[] arg1);
    public A withNewFailedMessage(char[] arg1,int arg2,int arg3);
    public A withNewFailedMessage(byte[] arg1,int arg2,int arg3);
    public A withNewFailedMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFailedMessage(String arg1);
    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public ScheduleStatus getScheduler();
    public ScheduleStatus buildScheduler();
    public A withScheduler(ScheduleStatus scheduler);
    public Boolean hasScheduler();
    public A withNewScheduler(String nextRecover,String nextStart);
    public TimeChaosStatusFluent.SchedulerNested<A> withNewScheduler();
    public TimeChaosStatusFluent.SchedulerNested<A> withNewSchedulerLike(ScheduleStatus item);
    public TimeChaosStatusFluent.SchedulerNested<A> editScheduler();
    public TimeChaosStatusFluent.SchedulerNested<A> editOrNewScheduler();
    public TimeChaosStatusFluent.SchedulerNested<A> editOrNewSchedulerLike(ScheduleStatus item);
    public interface ExperimentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExperimentStatusFluent<TimeChaosStatusFluent.ExperimentNested<N>> {

            public N and();
            public N endExperiment();    }


    public interface SchedulerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ScheduleStatusFluent<TimeChaosStatusFluent.SchedulerNested<N>> {

            public N and();
            public N endScheduler();    }


}
